@@ -268,7 +268,7 @@ See C<LICENSE> file and L<https://dev.perl.org/licenses/>
 
 =cut
 
-our $VERSION = '1.05';
+our $VERSION = '1.06';
 
 use Mojo::Base 'Mojolicious';
 
@@ -428,8 +428,11 @@ sub startup {
     # Skip set routing (optional)
     return $self unless $all_features || is_true_flag($opts->{init_api_routes});
 
+    # General routes related to the Suffit API
+    my $r = $self->routes;
+
     # API routes with token or cookie authorization
-    my $authorized = $self->routes->under('/api')->to('auth#is_authorized_api');
+    my $authorized = $r->under('/api')->to('auth#is_authorized')->name('api');
     $authorized->get('/')->to('API#api')->name('api-data');
     $authorized->get('/check')->to('API#check')->name('api-check');
     $authorized->get('/status')->to('API#status')->name('api-status');
@@ -524,7 +527,8 @@ sub _getToken {
         || '';
     if ($auth_string =~ /(Bearer|Token)\s+(.*)/) {
         $token = $2;
-        return '' unless $token =~ JWT_REGEXP;
+        return '' unless length($token) && $token =~ JWT_REGEXP;
+        return $token;
     }
 
     # In debug mode see "Token" config directive
